#
# spec file for package spirv-tools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 2017.0.g103
%define lname libSPIRV-Tools-suse4

Name:           spirv-tools
Version:        2017.0.g103
Release:        lp150.2.4
Summary:        API and commands for processing SPIR-V modules
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/KhronosGroup/SPIRV-Tools

Source:         %name-%version.tar.xz
Source9:        baselibs.conf
Patch1:         ver.diff
Patch2:         gcc48.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  cmake >= 2.8.12
BuildRequires:  gcc-c++
BuildRequires:  python3-base
BuildRequires:  python3-xml
BuildRequires:  spirv-headers >= 1.2

%description
The package includes an assembler, binary module parser,
disassembler, and validator for SPIR-V.

%package -n %lname
Summary:        SPIR-V tool component library
Group:          System/Libraries

%description -n %lname
The SPIR-V Tool library contains all of the implementation details
driving the SPIR-V assembler, binary module parser, disassembler and
validator, and is used in the standalone tools whilst also enabling
integration into other code bases directly.

%package devel
Summary:        Development headers for the SPIR-V tool library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The SPIR-V Tool library contains all of the implementation details
driving the SPIR-V assembler, binary module parser, disassembler and
validator, and is used in the standalone tools whilst also enabling
integration into other code bases directly.

%prep
%setup -q
%autopatch -p1

%build
%cmake -D"SPIRV-Headers_SOURCE_DIR=%_prefix" -DSPIRV_BUILD_COMPRESSION=BOOL:ON
make %{?_smp_mflags}

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/spirv-*
%doc LICENSE

%files -n %lname
%_libdir/libSPIRV-Tools.so.*
%_libdir/libSPIRV-Tools-comp.so.*
%_libdir/libSPIRV-Tools-link.so.*
%_libdir/libSPIRV-Tools-opt.so.*

%files devel
%_libdir/libSPIRV-Tools.so
%_libdir/libSPIRV-Tools-comp.so
%_libdir/libSPIRV-Tools-link.so
%_libdir/libSPIRV-Tools-opt.so
%_includedir/spirv-tools/

%changelog
* Thu Jan  4 2018 tchvatal@suse.com
- Make sure to build just with python3
- Remove needles buildroot variable and default defattrs
- Use autopatch to apply patches
* Fri Nov 17 2017 jengelh@inai.de
- Update to new snapshot 2017.0.g103
  * Update MARK-V to version 1.01
  * Add new checks to validate arithmetics pass
  * Recognize SPV_AMD_shader_fragment_mask
  * Add validate logicals pass to the validator
  * Detach MARK-V from the validator
* Tue Jul 18 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g145
  * Validation of type decls for SPV_KHR_16bit_storage
  * Allow using FPRoundingMode when see VK_KHR_16bit_storage
  * Validator parses and registers OpExtension
  * Validator checks if operands require extension
  * Validator dissallows unsupported Vulkan capability
  * Update capability tests for SPV_KHR_16bit_storage rev 7
  * Support SPV_AMD_gcn_shader
  * Add FlattenDecoration transform
  * Validator support for Variable Pointer extension.
  * Support SPV_KHR_storage_buffer_storage_class
  * Add SPIR-V 1.2 support, for OpenCL 2.2
  * Added extension SPV_VALIDATOR_ignore_type_decl_unique
  * Add support for SPV AMD extensions
  * MARK-V decoder supports extended instructions
  * DeadBranchElim: Improve algorithm to only remove blocks with
    no predecessors
  * Opt: Add new size-reduction passes to usage message.
  * Add multi-sequence move-to-front implementation.
  * Add MemPass, move all shared functions to it.
  * Add CommonUniformElim pass.
  * Mem2Reg: Allow Image and Sampler types as base target types.
* Mon Feb 20 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g28
  * The Signedness in OpTypeInt must always be 0.
- Add baselibs.conf [needed by libvulkan1, needed by libgtk4-0]
* Thu Feb  2 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g24
  * Add classes for representing SPIR-V language constructs in memory.
  * Add an option to spvBinaryToText() to ignore header output.
  * Add IrBuilder for constructing SPIR-V in-memory representation.
  * Add Pass, PassManager, and StripDebugInfoPass.
  * Add the spirv-opt command line tool.
  * Fixes segfault for loops without back-edges
  * Allow missing memory model instructions in modules.
  * Add spirv-lesspipe.sh
  * Add spirv-dis/spirv-as support for emacs when loading .spv binaries
- Add gcc48.diff
* Mon Jun 13 2016 jengelh@inai.de
- Initial package (version 1.1) for build.opensuse.org
- Add ver.diff
